==> ampache-7.4.2-2-any.pkg.tar.zst: usr/share/webapps/ampache/src/Gui/Catalog/CatalogDetails.php <==
<?php

declare(strict_types=0);

/**
 * vim:set softtabstop=4 shiftwidth=4 expandtab:
 *
 * LICENSE: GNU Affero General Public License, version 3 (AGPL-3.0-or-later)
 * Copyright Ampache.org, 2001-2024
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Ampache\Gui\Catalog;

use Ampache\Gui\GuiFactoryInterface;
use Ampache\Gui\Stats\CatalogStatsInterface;
use Ampache\Repository\Model\Catalog;

final readonly class CatalogDetails implements CatalogDetailsInterface
{
    public function __construct(private GuiFactoryInterface $guiFactory, private Catalog $catalog)
    {
    }

    public function getName(): string
    {
        return $this->catalog->name ?? '';
    }

    public function getFullInfo(): string
    {
        return scrub_out($this->catalog->f_info);
    }

    public function getLastUpdateDate(): string
    {
        return scrub_out($this->catalog->get_f_update());
    }

    public function getLastAddDate(): string
    {
        return scrub_out($this->catalog->get_f_add());
    }

    public function getLastCleanDate(): string
    {
        return scrub_out($this->catalog->get_f_clean());
    }

    public function getCatalogStats(): CatalogStatsInterface
    {
        return $this->guiFactory->createCatalogStats(
            Catalog::get_stats($this->catalog->id)
        );
    }
}

==> ampache-7.6.1-1-any.pkg.tar.zst: usr/share/webapps/ampache/src/Gui/Catalog/CatalogDetails.php <==
<?php

declare(strict_types=0);

/**
 * vim:set softtabstop=4 shiftwidth=4 expandtab:
 *
 * LICENSE: GNU Affero General Public License, version 3 (AGPL-3.0-or-later)
 * Copyright Ampache.org, 2001-2024
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Ampache\Gui\Catalog;

use Ampache\Gui\GuiFactoryInterface;
use Ampache\Gui\Stats\CatalogStatsInterface;
use Ampache\Repository\Model\Catalog;

final readonly class CatalogDetails implements CatalogDetailsInterface
{
    public function __construct(private GuiFactoryInterface $guiFactory, private Catalog $catalog)
    {
    }

    public function getName(): string
    {
        return $this->catalog->name ?? '';
    }

    public function getFullInfo(): string
    {
        return scrub_out($this->catalog->get_f_info());
    }

    public function getLastUpdateDate(): string
    {
        return scrub_out($this->catalog->get_f_update());
    }

    public function getLastAddDate(): string
    {
        return scrub_out($this->catalog->get_f_add());
    }

    public function getLastCleanDate(): string
    {
        return scrub_out($this->catalog->get_f_clean());
    }

    public function getCatalogStats(): CatalogStatsInterface
    {
        return $this->guiFactory->createCatalogStats(
            Catalog::get_stats($this->catalog->id)
        );
    }
}
